powered by
Calculate the next dose assignment for a TITE-IR design.
isotitedose(followup, DLT, assignment, obswin, doses, target = 1/3, safety = 0.05)
A vector of followup times
A vector of DLT results. FALSE or 0 is interpreted as no observed DLT and TRUE or 1 is interpreted as observed DLT.
FALSE
TRUE
a vector of dose assignments. Doses should be labeled in consecutive integers from 1 to number of dose levels.
The observation window with respect to which the MTD is defined.
An integer providing the number of doses.
Target DLT rate
The safety factor to prevent overly aggressive escalation
an integer specifying the recommended dose level
isotitesim for simulations
isotitesim
# NOT RUN { isotitedose(followup = c(6, 5, 4, 3, 2, 1), DLT = c(0, 0, 0, 0, 0, 0), assignment = c(1, 1, 1, 2, 2, 2), obswin = 6, doses = 6) # }
Run the code above in your browser using DataLab