powered by
Simulates trials based on the TITE-IR design.
isotitesim(PI, target, n, nsim, obswin = 1, rate = 1, safety = 0.05, accrual = "poisson", restrict = TRUE)
A vector of true toxicity probabilities at each dose
Target DLT rate
Sample size of the trial
Number of trial replicates
The observation window with respect to which the MTD is defined
Patient arrival rate: expected number of arrivals per observation window
The safety factor to prevent overly aggressive escalation
Specify the accrual distribution. Can be either "poisson" or "fixed". Partial strings are also acceptable.
"poisson"
"fixed"
If TRUE, do not allow escalation immediately after a toxic outcome (require coherent escalation)
TRUE
Object of type isotite which provides results from TITE-IR simulations
isotite
isotitedose for dose recommendation
isotitedose
# NOT RUN { isotitesim(PI = c(0.05, 0.10, 0.20, 0.30, 0.50, 0.70), target = 1/3, n = 24, nsim = 10, obswin = 6, rate = 12) # }
Run the code above in your browser using DataLab